@@ -47,14 +47,14 @@ def arg_parser():
     upload_file_path = args.path
 
     if args.check:
-        parse_config_old()
+        # check if all the prerequisites are met
         logger.log(message="All prerequisites met.", log_level="info", to_file=True, to_terminal=True)
         exit(0)
     elif args.upload:
         if radarType is None or version_name is None or upload_file_path is None:
             print('Please provide all the arguments: --type, --version, --source')
             exit(1)
-        parse_config_old()
+        # check if the radar type is valid
         validate(radarType, version_name)
         if check_upload_file(upload_file_path, version_name) is False:
             exit(1)
